package main

import (
	"encoding/json"
	"fmt"
	"io/ioutil"
	"log"
	"net/http"
	"time"
)

type Param struct {
	From       string `json:"from"`
	To         string `json:"to"`
	FromNumber string `json:"fromNumber"`
}

type ExtrInfo struct {
	From       string  `json:"from"`
	To         string  `json:"to"`
	FromNumber string  `json:"fromNumber"`
	Value      float32 `json:"result"`
}

type Result struct {
	Errorcode string `json:"errorcode"`
	ExtrInfo  `json:"extra"`
}

var currencyToCode = map[string]string{
	"人民币": "CNY",
	"港元":  "HKD",
	"台币":  "TWD",
	"欧元":  "EUR",
	"美元":  "USD",
	"英镑":  "GBP",
	"澳元":  "AUD",
	"韩元":  "KRW",
	"日元":  "JPY",
}

func queryHuilv(param *Param) float32 {
	fromCode := currencyToCode[param.From]
	toCode := currencyToCode[param.To]
	timestamp := time.Now().Unix()
	query := fmt.Sprintf("https://api.jijinhao.com/plus/convert.htm?from_tkc=%s&to_tkc=%s&amount=%s&_=%d000", fromCode, toCode, param.FromNumber, timestamp)
	resp, err := http.Get(query)
	if err != nil {
		return -1
	}
	defer resp.Body.Close()
	body, err := ioutil.ReadAll(resp.Body)
	var value float32 = -1
	fmt.Sscanf(string(body), "var result = '%f'", &value)
	return value
}

func Handler(w http.ResponseWriter, r *http.Request) {
	param := Param{}
	body, _ := ioutil.ReadAll(r.Body)
	json.Unmarshal(body, &param)
	value := queryHuilv(&param)
	if value < 0 {
		fmt.Fprintln(w, "{\"errorcode\": \"100200\",\"errmsg\": \"查询失败\"}")
		return
	}
	result := &Result{
		Errorcode: "100100",
		ExtrInfo: ExtrInfo{
			From:       param.From,
			To:         param.To,
			FromNumber: param.FromNumber,
			Value:      value,
		},
	}
	out, _ := json.Marshal(result)
	fmt.Fprintln(w, string(out))
	return
}

func main() {
	http.HandleFunc("/webhook-demo/huilv/query", Handler)
	if err := http.ListenAndServe("127.0.0.1:8080", nil); err != nil {
		log.Panicln(err)
	}
}
